fn remaining_allowance(
person: &DiscoveredPerson,
facts: &[&ExistingLinkingMailFact],
quiet_since: DateTime<Utc>,
) -> i64Expand description
How many mails the caps still allow this person for this course.
fn remaining_allowance(
person: &DiscoveredPerson,
facts: &[&ExistingLinkingMailFact],
quiet_since: DateTime<Utc>,
) -> i64How many mails the caps still allow this person for this course.